@@ -1,4 +1,4 @@
-from typing import Dict
+from typing import List
 import os
 import shutil
 import subprocess
@@ -10,20 +10,18 @@ import aws_cdk.aws_lambda as lambda_
 class AppLambdaLayer(lambda_.LayerVersion):
 
     def __init__(self, scope: core.Construct, construct_id: str,
-                 build_path: str = None,
-                 include: Dict[str, str] = None, **kwargs,
+                 scope_dir: str,
+                 include: List[str] = None, **kwargs,
                  ):
         """
         :param scope:
         :param construct_id:
-        :param build_path: Absolute build directory path
         :param include: Dictionary that maps absolute paths to be included to -> lambda layer paths
-        :param kwargs: compatible_runtimes (required), ...
+        :param kwargs: compatible_runtimes (required), ... passed down to lambda_.LayerVersion
         """
-        if build_path is None:
-            build_path = "_build/" + uuid4().hex
         if include is None:
             include = {}
+        build_path = "_build/" + uuid4().hex
 
         # clean build path
         shutil.rmtree(build_path, ignore_errors=True)
@@ -32,12 +30,23 @@ class AppLambdaLayer(lambda_.LayerVersion):
         # app lambda layer
         os.makedirs(f"{build_path}/app_lambda_layer/python")
         # app -> external requirements
-        subprocess.run(f"poetry export -f requirements.txt > app_lambda_layer/requirements.txt", cwd=build_path, shell=True)
-        subprocess.run(f"pip install -r app_lambda_layer/requirements.txt -t app_lambda_layer/python", cwd=build_path, shell=True)
+        subprocess.run(
+            f"poetry export -f requirements.txt > {os.path.abspath(f'{build_path}/app_lambda_layer/requirements.txt')}",
+            cwd=scope_dir,
+            shell=True,
+        )
+        subprocess.run(
+            f"pip install -r app_lambda_layer/requirements.txt -t app_lambda_layer/python",
+            cwd=build_path,
+            shell=True,
+        )
         # app -> include paths
         for path in include:
-            os.makedirs(f"{build_path}/app_lambda_layer/python/{include[path]}")
-            shutil.copytree(path, f"{build_path}/app_lambda_layer/python/{include[path]}", dirs_exist_ok=True)
+            os.makedirs(f"{build_path}/app_lambda_layer/python/{path}")
+            shutil.copytree(
+                f"{scope_dir}/{path}", f"{build_path}/app_lambda_layer/python/{path}",
+                dirs_exist_ok=True,
+            )
 
         # optimize (remove Lambda Runtime modules)
         lambda_included = [
